@@ -16,7 +16,6 @@ C = layout.grid.Col
 
 
 def base_data_tab(request):
-
     return layout.tabs.Tab(
         _("Personal data"),
         utils.grid_inside_tab(
@@ -41,6 +40,12 @@ def personal_data():
                 "last_name",
             ]
         ]
+        + [
+            hg.If(
+                hg.C("object.middle_name"),
+                utils.display_field_label_and_value("middle_name"),
+            )
+        ]
         + [
             hg.If(
                 hg.C("object.maiden_name"),
