@@ -45,6 +45,7 @@ class NaturalPersonEditPersonalDataView(EditView):
         "autogenerate_displayname",
         "first_name",
         "last_name",
+        "middle_name",
         "maiden_name",
         "gender",
         "date_of_birth",
@@ -88,6 +89,7 @@ class NaturalPersonEditPersonalDataView(EditView):
                 ),
                 R(C(F("first_name"))),
                 R(C(F("last_name"))),
+                R(C(F("middle_name"))),
                 R(C(F("maiden_name"))),
                 R(C(F("gender"))),
                 R(C(F("date_of_birth"))),
@@ -181,7 +183,6 @@ class EditEmailAddressView(EditView):
     fields = ["email", "type"]
 
     def form_valid(self, form, *args, **kwargs):
-
         ret = super().form_valid(form, *args, **kwargs)
         is_primary = form.cleaned_data["is_primary"]
         if is_primary:
